Learn R Programming

s2dv (version 1.1.0)

Corr: Compute the correlation coefficient between an array of forecast and their corresponding observation

Description

Calculate the correlation coefficient (Pearson, Kendall or Spearman) for an array of forecast and an array of observation. The correlations are computed along time_dim, the startdate dimension. If comp_dim is given, the correlations are computed only if obs along the comp_dim dimension are complete between limits[1] and limits[2], i.e., there is no NA between limits[1] and limits[2]. This option can be activated if the user wants to account only for the forecasts which the corresponding observations are available at all leadtimes. The confidence interval is computed by the Fisher transformation and the significance level relies on an one-sided student-T distribution. If the dataset has more than one member, ensemble mean is necessary necessary before using this function since it only allows one dimension 'dat_dim' to have inconsistent length between 'exp' and 'obs'. If all the dimensions of 'exp' and 'obs' are identical, you can simply use apply() and cor() to compute the correlation.

Usage

Corr(
  exp,
  obs,
  time_dim = "sdate",
  dat_dim = "dataset",
  comp_dim = NULL,
  limits = NULL,
  method = "pearson",
  memb_dim = NULL,
  memb = TRUE,
  pval = TRUE,
  conf = TRUE,
  conf.lev = 0.95,
  ncores = NULL
)

Arguments

exp

A named numeric array of experimental data, with at least two dimensions 'time_dim' and 'dat_dim'.

obs

A named numeric array of observational data, same dimensions as parameter 'exp' except along 'dat_dim' and 'memb_dim'.

time_dim

A character string indicating the name of dimension along which the correlations are computed. The default value is 'sdate'.

dat_dim

A character string indicating the name of dataset (nobs/nexp) dimension. The default value is 'dataset'.

comp_dim

A character string indicating the name of dimension along which obs is taken into account only if it is complete. The default value is NULL.

limits

A vector of two integers indicating the range along comp_dim to be completed. The default is c(1, length(comp_dim dimension)).

method

A character string indicating the type of correlation: 'pearson', 'spearman', or 'kendall'. The default value is 'pearson'.

memb_dim

A character string indicating the name of the member dimension. It must be one dimension in 'exp' and 'obs'. If there is no member dimension, set NULL. The default value is NULL.

memb

A logical value indicating whether to remain 'memb_dim' dimension (TRUE) or do ensemble mean over 'memb_dim' (FALSE). Only functional when 'memb_dim' is not NULL. The default value is TRUE.

pval

A logical value indicating whether to compute or not the p-value of the test Ho: Corr = 0. The default value is TRUE.

conf

A logical value indicating whether to retrieve the confidence intervals or not. The default value is TRUE.

conf.lev

A numeric indicating the confidence level for the regression computation. The default value is 0.95.

ncores

An integer indicating the number of cores to use for parallel computation. The default value is NULL.

Value

A list containing the numeric arrays with dimension: c(nexp, nobs, exp_memb, obs_memb, all other dimensions of exp except time_dim and memb_dim). nexp is the number of experiment (i.e., 'dat_dim' in exp), and nobs is the number of observation (i.e., 'dat_dim' in obs). exp_memb is the number of member in experiment (i.e., 'memb_dim' in exp) and obs_memb is the number of member in observation (i.e., 'memb_dim' in obs).

$corr

The correlation coefficient.

$p.val

The p-value. Only present if pval = TRUE.

$conf.lower

The lower confidence interval. Only present if conf = TRUE.

$conf.upper

The upper confidence interval. Only present if conf = TRUE.

Examples

Run this code
# NOT RUN {
# Case 1: Load sample data as in Load() example: 
example(Load) 
clim <- Clim(sampleData$mod, sampleData$obs) 
ano_exp <- Ano(sampleData$mod, clim$clim_exp) 
ano_obs <- Ano(sampleData$obs, clim$clim_obs) 
runmean_months <- 12 

# Smooth along lead-times   
smooth_ano_exp <- Smoothing(ano_exp, runmeanlen = runmean_months) 
smooth_ano_obs <- Smoothing(ano_obs, runmeanlen = runmean_months) 
required_complete_row <- 3  # Discard start dates which contain any NA lead-times 
leadtimes_per_startdate <- 60 
corr <- Corr(MeanDims(smooth_ano_exp, 'member'),              
            MeanDims(smooth_ano_obs, 'member'),              
            comp_dim = 'ftime',              
            limits = c(ceiling((runmean_months + 1) / 2),                         
            leadtimes_per_startdate - floor(runmean_months / 2))) 

# Case 2: Keep member dimension
corr <- Corr(smooth_ano_exp, smooth_ano_obs, memb_dim = 'member')
# ensemble mean
corr <- Corr(smooth_ano_exp, smooth_ano_obs, memb_dim = 'member', memb = FALSE)

# }

Run the code above in your browser using DataLab